for (var x in y) {
  for (;;) {
    babelHelpers.objectDestructuringEmpty(x);
  }
}
for (var _x in y) {
  for (babelHelpers.objectDestructuringEmpty(_x);;) {
    ;
  }
}
for (var _x2 in y) {
  for (; _x3 = _x2, babelHelpers.objectDestructuringEmpty(_x3), _x3; _x4 = _x2, babelHelpers.objectDestructuringEmpty(_x4), _x4) {
    var _x3, _x4;
    babelHelpers.objectDestructuringEmpty(_x2);
  }
}
for (babelHelpers.objectDestructuringEmpty(0); 0;) {
  ;
}
